.. py:function:: sf_Chi(x [, ret])

    Wrapper for :c:func:`gsl_sf_Chi`
    c code signature: double gsl_sf_Chi(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_Chi_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_Chi_e`
    c code signature: int gsl_sf_Chi_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_Ci(x [, ret])

    Wrapper for :c:func:`gsl_sf_Ci`
    c code signature: double gsl_sf_Ci(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_Ci_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_Ci_e`
    c code signature: int gsl_sf_Ci_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_Shi_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_Shi_e`
    c code signature: int gsl_sf_Shi_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_Shi(x [, ret])

    Wrapper for :c:func:`gsl_sf_Shi`
    c code signature: double gsl_sf_Shi(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_Si_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_Si_e`
    c code signature: int gsl_sf_Si_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_Si(x [, ret])

    Wrapper for :c:func:`gsl_sf_Si`
    c code signature: double gsl_sf_Si(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_atanint(x [, ret])

    Wrapper for :c:func:`gsl_sf_atanint`
    c code signature: double gsl_sf_atanint(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_atanint_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_atanint_e`
    c code signature: int gsl_sf_atanint_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_exprel(x [, ret])

    Wrapper for :c:func:`gsl_sf_exprel`
    c code signature: double gsl_sf_exprel(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_expm1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expm1_e`
    c code signature: int gsl_sf_expm1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_exp_err_e(x, dx [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_exp_err_e`
    c code signature: int gsl_sf_exp_err_e(const double x, const double dx, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double x: positional argument 0
    :param double dx: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_expint_En_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_En_e`
    c code signature: int gsl_sf_expint_En_e(const int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_exp_mult_err_e(x, dx, y, dy [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_exp_mult_err_e`
    c code signature: int gsl_sf_exp_mult_err_e(const double x, const double dx, const double y, const double dy, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rl__Ord`
    
    :param double x: positional argument 0
    :param double dx: positional argument 1
    :param double y: positional argument 2
    :param double dy: positional argument 3
    :param int ret: positional argument 4
    :param double result.val: positional argument 5
    :param double result.err: positional argument 6
    :rtype:  tuple(:param int ret: positional argument 4, :param double result.val: positional argument 5, :param double result.err: positional argument 6) 
    :return: result 

.. py:function:: sf_expint_Ei_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_Ei_scaled`
    c code signature: double gsl_sf_expint_Ei_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_expint_E2(x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_E2`
    c code signature: double gsl_sf_expint_E2(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_exp_mult(x, y [, ret])

    Wrapper for :c:func:`gsl_sf_exp_mult`
    c code signature: double gsl_sf_exp_mult(const double x, const double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_expint_E2_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_E2_e`
    c code signature: int gsl_sf_expint_E2_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_expint_3_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_3_e`
    c code signature: int gsl_sf_expint_3_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_exp(x [, ret])

    Wrapper for :c:func:`gsl_sf_exp`
    c code signature: double gsl_sf_exp(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_exprel_2(x [, ret])

    Wrapper for :c:func:`gsl_sf_exprel_2`
    c code signature: double gsl_sf_exprel_2(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_exp_mult_e(x, y [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_exp_mult_e`
    c code signature: int gsl_sf_exp_mult_e(const double x, const double y, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_expint_En_scaled(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_En_scaled`
    c code signature: double gsl_sf_expint_En_scaled(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_exprel_n_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_exprel_n_e`
    c code signature: int gsl_sf_exprel_n_e(const int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_exprel_n_CF_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_exprel_n_CF_e`
    c code signature: int gsl_sf_exprel_n_CF_e(const double n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_expint_En_scaled_e(n, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_En_scaled_e`
    c code signature: int gsl_sf_expint_En_scaled_e(const int n, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_expint_E1(x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_E1`
    c code signature: double gsl_sf_expint_E1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_expint_Ei(x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_Ei`
    c code signature: double gsl_sf_expint_Ei(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_exprel_n(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_exprel_n`
    c code signature: double gsl_sf_exprel_n(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_expint_E1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_E1_e`
    c code signature: int gsl_sf_expint_E1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_exp_mult_e10_e(x, y [, ret, result])

    Wrapper for :c:func:`gsl_sf_exp_mult_e10_e`
    c code signature: int gsl_sf_exp_mult_e10_e(const double x, const double y, gsl_sf_result_e10* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Oerd`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param int ret: positional argument 2
    :param gsl_sf_result_e10 result: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 2, :param gsl_sf_result_e10 result: positional argument 3) 
    :return: result 

.. py:function:: sf_exprel_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_exprel_e`
    c code signature: int gsl_sf_exprel_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_expint_E1_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_E1_scaled_e`
    c code signature: int gsl_sf_expint_E1_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_expint_E2_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_E2_scaled`
    c code signature: double gsl_sf_expint_E2_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_exp_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_exp_e`
    c code signature: int gsl_sf_exp_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_expint_E1_scaled(x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_E1_scaled`
    c code signature: double gsl_sf_expint_E1_scaled(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_expint_En(n, x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_En`
    c code signature: double gsl_sf_expint_En(const int n, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int n: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_exp_e10_e(x [, ret, result])

    Wrapper for :c:func:`gsl_sf_exp_e10_e`
    c code signature: int gsl_sf_exp_e10_e(const double x, gsl_sf_result_e10* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Oerd`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param gsl_sf_result_e10 result: positional argument 2
    :rtype:  tuple(:param int ret: positional argument 1, :param gsl_sf_result_e10 result: positional argument 2) 
    :return: result 

.. py:function:: sf_exp_err_e10_e(x, dx [, ret, result])

    Wrapper for :c:func:`gsl_sf_exp_err_e10_e`
    c code signature: int gsl_sf_exp_err_e10_e(const double x, const double dx, gsl_sf_result_e10* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Oerd`
    
    :param double x: positional argument 0
    :param double dx: positional argument 1
    :param int ret: positional argument 2
    :param gsl_sf_result_e10 result: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 2, :param gsl_sf_result_e10 result: positional argument 3) 
    :return: result 

.. py:function:: sf_expint_Ei_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_Ei_scaled_e`
    c code signature: int gsl_sf_expint_Ei_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_expm1(x [, ret])

    Wrapper for :c:func:`gsl_sf_expm1`
    c code signature: double gsl_sf_expm1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_expint_Ei_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_Ei_e`
    c code signature: int gsl_sf_expint_Ei_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_expint_E2_scaled_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_expint_E2_scaled_e`
    c code signature: int gsl_sf_expint_E2_scaled_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_expint_3(x [, ret])

    Wrapper for :c:func:`gsl_sf_expint_3`
    c code signature: double gsl_sf_expint_3( double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_exprel_2_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_exprel_2_e`
    c code signature: int gsl_sf_exprel_2_e( double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_exp_mult_err_e10_e(x, dx, y, dy [, ret, result])

    Wrapper for :c:func:`gsl_sf_exp_mult_err_e10_e`
    c code signature: int gsl_sf_exp_mult_err_e10_e(const double x, const double dx, const double y, const double dy, gsl_sf_result_e10* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d_d__Rl__Oerd`
    
    :param double x: positional argument 0
    :param double dx: positional argument 1
    :param double y: positional argument 2
    :param double dy: positional argument 3
    :param int ret: positional argument 4
    :param gsl_sf_result_e10 result: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 4, :param gsl_sf_result_e10 result: positional argument 5) 
    :return: result 

